#!/bin/bash
#Script     	: aider_install.sh
#Apps			: MRDEVS TOOLS
#Description	: Instalar Aider (asistente de codificación con IA)
#Author			: Cortana Rosero One <cortana@rosero.one>
#Generated by	: Claude Code (claude-3-7-sonnet-20250219)
#Created		: 2025/03/20 11:05:23
#Modified		: 2025/03/20 11:05:23
#Version		: 1.2.0
#Use Notes		:
#==============================================================================
# Derechos de Autor [2025] [Mauro Rosero P. <mauro@rosero.one>]
#==============================================================================
# Este programa es software libre: usted puede redistribuirlo y/o modificarlo
# bajo los términos de la Licencia Pública Affero General de GNU tal como
# lo publica la Free Software Foundation, ya sea la versión 3 de la licencia,
# o (a su elección) cualquier versión posterior.
#
# Este programa se distribuye con la esperanza de que sea útil,
# pero SIN NINGUNA GARANTÍA; sin siquiera la garantía implícita de
# COMERCIABILIDAD o IDONEIDAD PARA UN PROPÓSITO PARTICULAR. Consulte la
# Licencia Pública Affero General de GNU para obtener más detalles.
#
# Debería haber recibido una copia de la Licencia Pública Affero General
# junto con este programa. Si no la recibió, consulte <https://www.gnu.org/licenses/>.

# Configuración inicial
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
BIN_BASE="bin"
BIN_LIBS="lib"
BIN_MESG="msg"
BIN_CFGS="config"

# Leer DEVSPATH desde el archivo de configuración o usar "devs" por defecto
if [ -f "$SCRIPT_DIR/$BIN_CFGS/devspath.dat" ]; then
  DEVSPATH=$(cat "$SCRIPT_DIR/$BIN_CFGS/devspath.dat")
else
  DEVSPATH="devs"
fi
BIN_HOME="$HOME/$DEVSPATH"
VERSION=$(cat "$BIN_HOME/$BIN_BASE/$BIN_CFGS/version")
BIN_PATH=$BIN_HOME/$BIN_BASE

# CHECK SHELL LANGUAGE
BIN_LANG=${LANG:0:2}

# Importar bibliotecas necesarias
source "${BIN_HOME}/${BIN_BASE}/${BIN_LIBS}/base.lib"

# Cargar mensajes en el idioma del sistema o español por defecto
load_messages "${BIN_HOME}/${BIN_BASE}" "${BIN_MESG}" "${BIN_LANG}" "head"
load_messages "${BIN_HOME}/${BIN_BASE}" "${BIN_MESG}" "${BIN_LANG}" "developers"

# Variables globales
title="${head_000} ${aimsg_000}"
AIDER_VENV="$HOME/.aider-venv"




# Función para instalar aider
install_aider() {
  echo "${aimsg_009}"
  curl -LsSf https://aider.chat/install.sh | sh
  
  # El script de instalación de aider ya maneja la configuración y el alias
}

# Función para desinstalar aider
uninstall_aider() {
  echo "${aimsg_014}"
  
  # Ejecutar el desinstalador de aider si existe
  if [ -f "$HOME/.local/bin/aider-uninstall" ]; then
    $HOME/.local/bin/aider-uninstall
  fi
  
  # Remover archivos de aider
  rm -rf "$HOME/.aider"
  rm -f "$HOME/.local/bin/aider"
  rm -f "$HOME/.local/bin/aider-uninstall"
  
  echo "${aimsg_016}"
}

# Función para mostrar uso
show_usage() {
  echo "${aimsg_017}"
  echo "${aimsg_018}"
  echo "${aimsg_019}"
  echo "${aimsg_020}"
  echo "${aimsg_021}"
}

# Función principal
main() {
  # Verificar parámetros
  if [ "$1" = "-h" ] || [ "$1" = "--help" ]; then
    show_usage
    exit 0
  elif [ "$1" = "-u" ] || [ "$1" = "--uninstall" ]; then
    uninstall_aider
    exit 0
  else
    # Instalar aider directamente
    install_aider
    
    echo ""
    echo "${aimsg_022}"
    echo "${aimsg_023}"
    echo "${aimsg_024}"
  fi
}

# Ejecutar función principal con los parámetros recibidos
main "$@"