#!/bin/bash
#Script     	: sora_enable.sh
#Apps			: MRDEVS TOOLS
#Description	: Habilitar el alias 'sora' para Aider
#Author			: Sora Rosero One <sora@rosero.one>
#Generated by	: Claude Code (claude-3-7-sonnet-20250219)
#Created		: 2025/03/20 12:30:00
#Modified		: 2025/03/20 12:48:05
#Version		: 1.0.0
#Use Notes		:
#   ./sora_enable.sh          -> Habilitar
#	No usa console.lib, ni console.es
#==============================================================================
# Derechos de Autor [2025] [Mauro Rosero P. <mauro@rosero.one>]
#==============================================================================
# Este programa es software libre: usted puede redistribuirlo y/o modificarlo
# bajo los términos de la Licencia Pública Affero General de GNU tal como
# lo publica la Free Software Foundation, ya sea la versión 3 de la licencia,
# o (a su elección) cualquier versión posterior.
#
# Este programa se distribuye con la esperanza de que sea útil,
# pero SIN NINGUNA GARANTÍA; sin siquiera la garantía implícita de
# COMERCIABILIDAD o IDONEIDAD PARA UN PROPÓSITO PARTICULAR. Consulte la
# Licencia Pública Affero General de GNU para obtener más detalles.
#
# Debería haber recibido una copia de la Licencia Pública Affero General
# junto con este programa. Si no la recibió, consulte <https://www.gnu.org/licenses/>.

# Configuración inicial
# Usar DEVELOPER_DIR de base.lib
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
BIN_BASE="bin"
BIN_LIBS="lib"
BIN_MESG="msg"
BIN_CFGS="config"

# Leer DEVSPATH desde el archivo de configuración o usar "devs" por defecto
if [ -f "$SCRIPT_DIR/config/devspath.dat" ]; then
  DEVSPATH=$(cat "$SCRIPT_DIR/$BIN_CFGS/devspath.dat")
else
  DEVSPATH="devs"
fi

BIN_HOME="$HOME/$DEVSPATH"
VERSION=$(cat "$BIN_HOME/$BIN_BASE/$BIN_CFGS/version")

# CHECK SHELL LANGUAGE
BIN_LANG=${LANG:0:2}

# Importar bibliotecas necesarias
source "${BIN_HOME}/${BIN_BASE}/${BIN_LIBS}/base.lib"

# Cargar mensajes en el idioma del sistema o español por defecto
load_messages "${BIN_HOME}/${BIN_BASE}" "${BIN_MESG}" "${BIN_LANG}" "head"
load_messages "${BIN_HOME}/${BIN_BASE}" "${BIN_MESG}" "${BIN_LANG}" "developers"
title="${head_000} ${srmsg_000}"

# Verificar que 'dialog' esté instalado
if ! command -v dialog &>/dev/null; then
  echo "${npm_001}"
  clear
  exit 1
fi

# Función para agregar alias de Sora para Aider
sora_alias() {
    local alias_nombre="sora"
    local alias_comando=""
    local shell_config=""
    
    # Determinar la ruta del comando aider
    if [[ -x "$HOME/.local/bin/aider" ]]; then
        alias_comando="$HOME/.local/bin/aider"
    else
        alias_comando="aider" # Fallback al comando en el PATH
    fi
    
    # Detectar el shell actual y seleccionar el archivo de configuración adecuado
    case "$SHELL" in
        */bash)
            shell_config="$HOME/.bashrc"
            ;;
        */zsh)
            shell_config="$HOME/.zshrc"
            ;;
        *)
            dialog --backtitle "${title}" --title "${head_error}" --msgbox "${srmsg_021}" 7 50
            return 1
            ;;
    esac

    # Verificar si el alias ya existe en el archivo de configuración
    if grep -q "alias $alias_nombre=" "$shell_config"; then
        dialog --backtitle "${title}" --title "${srmsg_008}" --msgbox "${srmsg_004} $shell_config" 7 60
        return 2
    else
        # Agregar el alias al final del archivo de configuración
        echo "alias $alias_nombre='$alias_comando'" >> "$shell_config"
        if [[ $? -eq 0 ]]; then
            # Recargar el archivo de configuración
            source "$shell_config" 2>/dev/null || true
            dialog --backtitle "${title}" --title "${srmsg_009}" --msgbox "${srmsg_005} $shell_config\n\nRecuerde ejecutar: source $shell_config" 9 60
        else
            dialog --backtitle "${title}" --title "${head_error}" --msgbox "${srmsg_019}" 7 50
            return 1
        fi
    fi
}

# Confirmar activación
dialog --backtitle "${title}" --title "${npm_031}" --yesno "${srmsg_002}" 7 50
if [[ $? -eq 0 ]]; then
  # Crear un archivo fuente para la activación del alias
  ALIAS_FILE="$BIN_HOME/bin/sora_alias.sh"
  echo '#!/bin/bash' > "$ALIAS_FILE"
  echo '# Verificar si ~/.local/bin está en el PATH' >> "$ALIAS_FILE"
  echo 'if [[ ":$PATH:" != *":$HOME/.local/bin:"* ]]; then' >> "$ALIAS_FILE"
  echo '  # Si no está en el PATH, usamos la ruta completa en el alias' >> "$ALIAS_FILE"
  echo '  alias sora="$HOME/.local/bin/aider"' >> "$ALIAS_FILE"
  echo 'else' >> "$ALIAS_FILE"
  echo '  # Si está en el PATH, podemos usar el nombre directamente' >> "$ALIAS_FILE"
  echo '  alias sora="aider"' >> "$ALIAS_FILE"
  echo 'fi' >> "$ALIAS_FILE"
  echo "echo \"${srmsg_017}\"" >> "$ALIAS_FILE"
  chmod +x "$ALIAS_FILE"
  
  # Ejecutar la función sora_alias para el archivo de configuración permanente
  sora_alias
  
  # Crear un mensaje con instrucciones para activar el alias en la sesión actual
  dialog --backtitle "${title}" --title "${srmsg_008}" --msgbox "${srmsg_006}\n\n${srmsg_007}\n\nsource $ALIAS_FILE\n\n" 10 70
else
  dialog --backtitle "${title}" --title "${head_canceled}" --msgbox "${npm_008}" 6 40
  clear
  exit 1
fi

# Limpiar consola
clear
